@@ -4,6 +4,7 @@ from flask import jsonify, request
 from datetime import datetime, timedelta
 
 from blueflask.lib.errors import internal_error, bad_request, not_found
+
 from blueflask.lib.infos import success
 
 from ...consts import CONFIG, SERVICE_CODE, LOGS
@@ -13,7 +14,6 @@ from ... import getsms as lib_customer
 
 import json
 import pika
-import logging
 
 
 @api.route('/sms', methods=['POST'])
@@ -78,87 +78,82 @@ def send_sms():
     params = request.args or {}
     headers = request.headers or {}
     json_doc = request.get_json() or {}
-    msisdn = json_doc["msisdn"]
 
     LOGS.logger.info(
         "Incoming SMS: Parameters={} headers={} json={}"
         .format(params, headers, json_doc)
     )
-
-    telma = (msisdn[-9:]).startswith("34")
-
+    msisdn_sender_id_list = []
     smpp = json_doc.get('sender_id')
-    # if smpp == "mfs":
-    #     sender_id = "mfs"
-    if telma:
-        LOGS.logger.info("MSISDN Telma redirected to Orange SMPP.")
-        sender_id = "orange"
-    elif smpp == "mfs":
-        sender_id = "mfs"
-    elif not telma and smpp == 'orange':
-        LOGS.logger.warning(
-            "MSISDN '{}' is not Telma but targeting Orange SMPP. "
-            "Redirected to default SMPP."
-            .format(msisdn)
-        )
-        sender_id = "Blueline"
+
+    if ',' in json_doc["msisdn"]:
+        msisdns = json_doc["msisdn"].replace(' ', '')
+        msisdns = msisdns.split(',')
+
+        for msisdn in msisdns:
+            sender_id = define_sender_id(msisdn, smpp, user)
+            LOGS.logger.info('[{} sent to smpp {}]'.format(msisdn, sender_id))
+            msisdn_sender_id_list.append((msisdn, sender_id))
     else:
-        if user.startswith('partenaire'):
-            sender_id = user.split('_')[1]
-        else:
-            sender_id = json_doc.get('sender_id', 'bip')
+        sender_id = define_sender_id(json_doc["msisdn"], smpp, user)
+        LOGS.logger.info(
+            '[{} sent to smpp {}'.format(json_doc["msisdn"], sender_id))
+        msisdn_sender_id_list.append((json_doc["msisdn"], sender_id))
 
-    try:
-        json_doc['sender_id'] = sender_id
-        queue = CONFIG[sender_id]['account']
-    except KeyError:
-        return bad_request(
-            message="Le sender_id n'exist pas",
-            code='{}-{}'.format(
-                SERVICE_CODE,
-                '4001'
-                ),
-            service_code=SERVICE_CODE
-            )
-
-    document = {
-        'auth': auth or (),
-        'params': params,
-        'headers': headers,
-        'json': json_doc
-        }
-
-    try:
-        connection = pika.BlockingConnection(
-            pika.ConnectionParameters(
-                host='localhost',
-                virtual_host='/smsc'
+    for msisdn, sender_id in msisdn_sender_id_list:
+        try:
+            json_doc['sender_id'] = sender_id
+            json_doc['msisdn'] = msisdn
+            queue = CONFIG[sender_id]['account']
+        except KeyError:
+            return bad_request(
+                message="Le sender_id n'exist pas",
+                code='{}-{}'.format(
+                    SERVICE_CODE,
+                    '4001'
+                    ),
+                service_code=SERVICE_CODE
                 )
-            )
-        LOGS.logger.info('[{}] Connection to Pika established'.format(msisdn))
-    except Exception:
-        # exception de connection lancée par pika
-        # il faut que rabbitmq-server soit installé
-        # et que le vhost /{service} existe déjà
-        return internal_error(
-            message="serveur RabbitMQ injoignable",
-            code='{}-5000'.format(SERVICE_CODE),
-            service_code=SERVICE_CODE
-            )
-    else:
-        channel = connection.channel()
-        channel.exchange_declare(
-            exchange='sendsms',
-            exchange_type='topic'
-            )
-        # déclaration idempotente: pas grave si l'exchange existe déjà
-        channel.basic_publish(
-            exchange='sendsms',
-            routing_key=queue,
-            body=json.dumps(document),
-            properties=pika.BasicProperties(delivery_mode=2)
-            )
-        connection.close()
+
+        document = {
+            'auth': auth or (),
+            'params': params,
+            'headers': headers,
+            'json': json_doc
+            }
+
+        try:
+            connection = pika.BlockingConnection(
+                pika.ConnectionParameters(
+                    host='localhost',
+                    virtual_host='/smsc'
+                    )
+                )
+            LOGS.logger.info('[{}] Connection '
+                             'to Pika established'.format(document))
+        except Exception:
+            # exception de connection lancée par pika
+            # il faut que rabbitmq-server soit installé
+            # et que le vhost /{service} existe déjà
+            return internal_error(
+                message="serveur RabbitMQ injoignable",
+                code='{}-5000'.format(SERVICE_CODE),
+                service_code=SERVICE_CODE
+                )
+        else:
+            channel = connection.channel()
+            channel.exchange_declare(
+                exchange='sendsms',
+                exchange_type='topic'
+                )
+            # déclaration idempotente: pas grave si l'exchange existe déjà
+            channel.basic_publish(
+                exchange='sendsms',
+                routing_key=queue,
+                body=json.dumps(document),
+                properties=pika.BasicProperties(delivery_mode=2)
+                )
+            connection.close()
     return success(service_code=SERVICE_CODE)
 
 
@@ -412,4 +407,26 @@ def connect_sms(uuid):
             )
     return jsonify(result)
 
+
+def define_sender_id(msisdn, smpp, user):
+    telma = (msisdn[-9:]).startswith("34")
+    # if smpp == "mfs":
+    #     sender_id = "mfs"
+    if telma:
+        LOGS.logger.info("MSISDN Telma redirected to Orange SMPP.")
+        sender_id = "orange"
+    elif smpp == "mfs":
+        sender_id = "mfs"
+    elif not telma and smpp == 'orange':
+        LOGS.logger.warning(
+            "MSISDN '{}' is not Telma but targeting Orange SMPP. "
+            "Redirected to default SMPP.".format(msisdn)
+        )
+        sender_id = "Blueline"
+    else:
+        if user.startswith('partenaire'):
+            sender_id = user.split('_')[1]
+        else:
+            sender_id = smpp or 'bip'
+    return sender_id
 # EOF
